@@ -30,9 +30,10 @@ Checks can be referred to from branch protection rules, in order to prevent faul
   runtime.
 
 """
-
+import base64
 from dataclasses import dataclass
 from datetime import datetime
+from logging import Logger
 from pathlib import Path
 from typing import Dict, Optional
 
@@ -42,8 +43,8 @@ from github.PullRequest import PullRequest
 from github.Repository import Repository as GithubRepository
 
 from . import Reporter
-from ..markdown import run_result_to_markdown
-from ..simple import to_string
+from ...reporting.formatting.markdown import run_result_to_markdown
+from ...reporting.formatting.text import to_string
 from ...steps.models import RunProperties
 from ...steps.run import RunResult
 from ...utilities.repo import Repository, RepoConfig
@@ -51,11 +52,16 @@ from ...utilities.repo import Repository, RepoConfig
 
 @dataclass
 class GithubAppConfig:
-    private_app_key_path: str
+    private_app_key_path: Optional[str]
+    private_key_base_64_encoded: Optional[str]
     app_key: str
 
     def __init__(self, config: Dict):
-        self.private_app_key_path = config['privateKeyPath']
+        self.private_app_key_path = config.get('privateKeyPath')
+        self.private_key_base_64_encoded = config.get('privateKeyBase64Encoded')
+        if not self.private_key_base_64_encoded and not self.private_app_key_path:
+            raise KeyError("Either 'privateKeyPath' or 'privateKeyBase64Encoded' need to be defined")
+
         self.app_key = config['appId']
 
 
@@ -119,14 +125,15 @@ class CommitCheck(Reporter):
     _config: GithubConfig
     _check_run_id: Optional[int]
 
-    def __init__(self, config: Dict):
+    def __init__(self, config: Dict, logger: Logger):
         self._config = GithubConfig(config)
         self.git_repository = Repository(RepoConfig(config))
         self._check_run_id = None
+        self._logger = logger
 
     @staticmethod
     def _to_output(results: RunResult) -> dict:
-        build_id = results.run_properties.build_id
+        build_id = results.run_properties.details.build_id
         summary = ':white_check_mark: Build successful' if results.is_success else ':x: Build failed'
         return {'title': f'Build {build_id}', 'summary': summary + '\n' + run_result_to_markdown(results),
                 'text': to_string(results)}
@@ -134,9 +141,12 @@ class CommitCheck(Reporter):
     def send_report(self, results: RunResult) -> None:
         config = self._config.app_config
         if not config:
-            raise ValueError("github.app config needs to be defined")
+            raise KeyError("github.app config needs to be defined")
+
+        private_key = Path(config.private_app_key_path or '').read_text(
+            encoding='utf-8') if config.private_app_key_path else base64.b64decode(
+            config.private_key_base_64_encoded or '').decode('utf-8')
 
-        private_key = Path(config.private_app_key_path).read_text(encoding='utf-8')
         integration = GithubIntegration(integration_id=config.app_key, private_key=private_key)
 
         install = integration.get_installation(self._config.owner, self._config.repo_name)
@@ -145,7 +155,9 @@ class CommitCheck(Reporter):
         repo = github.get_repo(self._config.repository)
         if self._check_run_id:
             run = repo.get_check_run(self._check_run_id)
-            run.edit(completed_at=datetime.now(), conclusion='success', output=self._to_output(results))
+            conclusion = 'success' if results.is_success else 'failure'
+            self._logger.info(f'Setting check to {conclusion}')
+            run.edit(completed_at=datetime.now(), conclusion=conclusion, output=self._to_output(results))
         else:
             self._check_run_id = repo.create_check_run(name='Pipeline build', head_sha=self.git_repository.get_sha,
                                                        status='in_progress').id
